#ifndef XSLTADDON_H
#define XSLTADDON_H

extern int timing;
extern int docbook;
extern int html;


/**
 * xslProcess:
 *@doc: valid xml data document
 *@cur: valid stylesheet to execute    
 *
 * Process stylesheet use xml data 
 */
void xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur,
                 const char *filename);

/*
---------------------------------------------------
         Debugger "add ons"
------------------------------------------------------
 */

/**
 * xsltAddonUsage:
 * @name : name of application
 *
 * Print the extra usage information provided by the debugger
 */
void xsltAddonUsage(const char *name);

/**
 * xslAddonVersion:
 *
 * Print version information for "addon on"
 */
void xslAddonVersion();


/* Gets called before any options are processed */

/**
 * xsltAddonInit:
 * @argc : arg count passed to xsltaddon
 * @argv : argv command line arguments  passed to xsltaddon
 *
 * Allow debugger to do setup
 */
void xsltAddonInit(int argc, char **argv);


/* Called before xsltaddon quits to allow debugger to free resources */

/**
 * xsltAddonQuit:
 *
 * Allow debugger to free resources
 */
void xsltAddonQuit();


/* Called to allow addon to take control */

/**
 * xsltAddonRun:
 * @nbparams : number of params as processed by xsladdon
 * @oarams : params as processed by xsladdon
 *
 * Allow debugger to take control
 */
void xsltAddonRun(int nbparams, char **params);


/* gets called after "--maxdepth" was not found */

/**
 * xsltAddonParseOptions:
 * @index : the argument being processed by xsltaddon
 *
 * Parse the extra options of the debugger
 *
 * Returns 1 if a valid option is found, 0 otherwise
 */
int xsltAddonParseOptions(int *index);


/* gets called after "--param" was not found */

/*
 * xsltAddonHandleOptions:
 * @index : the argument being processed by xsltaddon
 *
 * Parse the extra options of the debugger
 * 
 * Returns 1 if a valid option is found, 0 otherwise
 */
int xsltAddonHandleOptions(int *index);

#endif
